Improve this doc View Source

Filters are used for formatting data displayed to the user.

The general syntax in templates is as follows:

        {{ expression [| filter_name[:parameter_value] ... ] }}

## Usage

`$filter(name);`

### Arguments

Param | Type | Details
--- | --- | ---
name | String | Name of the filter function to retrieve

### Returns

Function | the filter function

## Example

Edit in Plunker

    <div ng-controller="MainCtrl">
     <h3>{{ originalText }}</h3>
     <h3>{{ filteredText }}</h3>
    </div>

    angular.module('filterExample', [])
    .controller('MainCtrl', function($scope, $filter) {
      $scope.originalText = 'hello';
      $scope.filteredText = $filter('uppercase')($scope.originalText);
    });